Contributors
============

In alphabetical order:

- Ben Boeckel
- Christian Geier
- Clément Mondon
- Hugo Osvaldo Barrera
- Julian Mehne
- Marek Marczykowski-Górecki
- Markus Unterwaditzer
- Michael Adler
- Thomas Weißschuh
